import java.util.*;
/**
 * This class is a simple example of 
 * using an ArrayList in J2SE 5.0.
 */
public class NameList {
  
  private ArrayList<String> names;
  
  /**
   * This constructor creates and initializes an ArrayList of Strings.
   */
  public NameList() {
    names = new ArrayList<String>();
    names.add("Sally");
    names.add("Splat");
    names.add("Google");
  }
  /**
   * Add a name to the end of the list.  If the argument is null,
   * it is silently ignored.
   * @param name the name to add
   */
  public void addName(String name) {
    if (name == null) return;
    names.add(name);
  }
  /**
   * Get a String containing a comma-separated list of
   * the names in the ArrayList.  Note the use of foreach.
   * @return String containing comma-separated list of names.
   */
  public String getCsNameList() {
    StringBuilder buf = new StringBuilder();
    for (String n : names) {
      if (buf.length() != 0) {
        buf.append(",");
      }
      buf.append(n);
    }
    return buf.toString();
  }
  /**
   * Get a SortedMap containing counts of the letters in the names given
   * in the name list.  Note the use of autoboxing.
   * @return Map<Character,Integer> one entry per character found
   */
  public SortedMap<Character,Integer> getCharacterMap() {
    SortedMap<Character,Integer> cMap = new TreeMap<Character,Integer>();
    for (String n : names) {
      for (int i=0; i<n.length(); i++) {
        char c = n.charAt(i);
        if (cMap.containsKey(c)) {
          int count = cMap.get(c);
          cMap.put(c,count+1);
        } else {
          cMap.put(c,1);
        }
      }
    }
    return cMap;
  }
}
